package com.example.youtube_videos.activity;


import java.util.List;
import java.util.logging.Logger;

import com.example.youtube_videos.R;
import com.example.youtube_videos.VideoAdapter;
import com.example.youtube_videos.R.id;
import com.example.youtube_videos.R.layout;
import com.example.youtube_videos.model.Video;
import com.example.youtube_videos.util.Util;

import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.LoaderManager;
import android.support.v4.app.LoaderManager.LoaderCallbacks;
import android.support.v4.content.AsyncTaskLoader;
import android.support.v4.content.Loader;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.TextView;

// we have to use FragmentActivity instead of Activity because we are using Loaders
// FragmentActivity is from support library v4
public class VideoListActivity extends FragmentActivity implements LoaderCallbacks<List<Video>> {

	private Logger log = Logger.getLogger(VideoListActivity.class.getName());
	
	public static final String EXTRA_USER = "extra-user";

	private String user;
	private ListView lvVideos;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_video_list);
		
		// get data passed from calling activity
		user = getIntent().getExtras().getString(EXTRA_USER);
		
		TextView tvUser = (TextView) findViewById(R.id.tv_user);
		tvUser.setText(user);
		
		lvVideos = (ListView) findViewById(R.id.list);
		
		getVideos();
	}
	
	private void getVideos() {
		// different way to load data in background - AsyncTaskLoader
		LoaderManager lm = getSupportLoaderManager();
		Bundle args = new Bundle();
		args.putString(EXTRA_USER, user);
		lm.initLoader(0, args, this).forceLoad(); // start the Loader
	}

	public Loader<List<Video>> onCreateLoader(int arg0, Bundle arg1) {
		final String user = arg1.getString(EXTRA_USER);
		
		return new AsyncTaskLoader<List<Video>>(this) {
			@Override
			public List<Video> loadInBackground() {
				// runs on a background thread
				List<Video> list = null;
				try {
					String response = Util.downloadVideos(user);
					list = Util.parseVideos(response);
				} catch(Exception e) {
					log.severe("An exception occurred: " + e.getMessage());
				}
				return list; 
			}
			
		};
	}

	public void onLoadFinished(Loader<List<Video>> arg0, List<Video> arg1) {
		// runs on the main thread
		final VideoAdapter adapter = new VideoAdapter(this, arg1); 
		lvVideos.setAdapter(adapter);
		
		lvVideos.setOnItemClickListener(new AdapterView.OnItemClickListener() {
			public void onItemClick(AdapterView<?> arg0, View arg1, int position, long arg3) {
				Video video = (Video) adapter.getItem(position);
				
				// let's open the link in some application
				Intent intent = new Intent(Intent.ACTION_VIEW, Uri.parse(video.getUrl()));
				startActivity(intent);
			}
		});
	}

	public void onLoaderReset(Loader<List<Video>> arg0) {}
	
	
	
	
}
