package com.example.youtube_videos.util;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import com.example.youtube_videos.model.UserDetail;
import com.example.youtube_videos.model.Video;

/** Just some utility functions:
 *  - simple download of data from the network
 *  - parsing some information from jsons
 *  
 * @author tomas
 *
 */
public class Util {

	public static String downloadUserDetail(String user) throws IOException {
		return downloadFromUrl("https://gdata.youtube.com/feeds/api/users/" + user + "?v=2&alt=json");
	}
	
	public static UserDetail parseUserDetail(String response) throws JSONException {
		JSONObject responseObject = new JSONObject(response);
		JSONObject entryObject = responseObject.getJSONObject("entry");
		String title = entryObject.getJSONObject("title").getString("$t");
		String description = entryObject.getJSONObject("summary").getString("$t");
		return new UserDetail(title, description);
	}
	
	public static String downloadVideos(String user) throws IOException {
		return downloadFromUrl("https://gdata.youtube.com/feeds/api/users/" + user + "/uploads?alt=json");
	}
	
	public static List<Video> parseVideos(String response) throws JSONException {
		List<Video> list = new ArrayList<Video>();
		
		JSONObject responseObject = new JSONObject(response);
		JSONObject feedObject = responseObject.getJSONObject("feed");
		JSONArray entryArray = feedObject.getJSONArray("entry");
		
		for (int i = 0; i < entryArray.length(); i++) {
			JSONObject itemObject = entryArray.getJSONObject(i);
			String title = itemObject.getJSONObject("title").getString("$t");
			JSONObject mediaObject = itemObject.getJSONObject("media$group");
			int duration = mediaObject.getJSONObject("yt$duration").getInt("seconds");
			String url = mediaObject.getJSONArray("media$player").getJSONObject(0).getString("url");
			list.add( new Video(title, duration, url) );
		}
		
		return list;
	}
	
	private static String downloadFromUrl(String urlStr) throws IOException {
		URL url = new URL(urlStr);
		HttpURLConnection urlConnection = (HttpURLConnection) url.openConnection();
		if(urlConnection.getResponseCode() == HttpURLConnection.HTTP_OK) {
			InputStream is = urlConnection.getInputStream();
			BufferedReader br = new BufferedReader(new InputStreamReader(is));
			StringBuffer sb = new StringBuffer();
			String line = null;
			while((line = br.readLine()) != null) {
				sb.append(line);
			}
			br.close();
			is.close();
			return sb.toString();
		} else {
			return null;
		}
	}
	
}
